<?php

class DB
{
    private static $db_username = "user";
    private static $db_password = "password";
    private static $db_host = "host";
    private static $db_name = "dbname";
    private static $db;

    function __construct()
    {
        try {
            self::$db = new PDO("mysql:host=" . self::$db_host . ";dbname=" . self::$db_name, self::$db_username, self::$db_password);
        } catch (PDOException $e) {
            echo "Datenbankverbindung gescheitert!";
            die();
        }
    }

    function checkEmailExists($email)
    {
        $stmt = self::$db->prepare("SELECT email FROM newsletter_user WHERE email=:email");
        $stmt->bindParam(":email", $email);

        if ($stmt->execute() && $stmt->rowCount()) {
            return true;
        } else {
            return false;
        }
    }

    function subscribeToNewsletter($name, $email, $optin_key)
    {
        $stmt = self::$db->prepare("INSERT INTO newsletter_user (name, email, optin_key) VALUES(:name, :email, :optin_key)");
        $stmt->bindParam(":name", $name);
        $stmt->bindParam(":email", $email);
        $stmt->bindParam(":optin_key", $optin_key);

        if ($stmt->execute() && $stmt->rowCount()) {
            return true;
        } else {
            return false;
        }
    }

    function confirmOptinKey($optin_key)
    {
        $stmt = self::$db->prepare("UPDATE newsletter_user SET bestaetigt=1 WHERE optin_key=:optin_key");
        $stmt->bindParam(":optin_key", $optin_key);

        if ($stmt->execute() && $stmt->rowCount()) {
            return true;
        } else {
            return false;
        }
    }

    function checkConfirmOptinKey($optin_key)
    {
        $stmt = self::$db->prepare("SELECT email, bestaetigt FROM newsletter_user WHERE optin_key=:optin_key");
        $stmt->bindParam(":optin_key", $optin_key);

        if ($stmt->execute()) {
            return $stmt->fetch();
        } else {
            return false;
        }
    }

    function getAllConfirmedNewsletterEmails()
    {
        $stmt = self::$db->prepare("SELECT id, email, name FROM newsletter_user WHERE bestaetigt=1");

        if ($stmt->execute()) {
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } else {
            return false;
        }
    }

    function writeNewsletterToDB($betreff, $inhalt)
    {
        $stmt = self::$db->prepare("INSERT INTO newsletter_mail (betreff, inhalt) VALUES(:betreff, :inhalt)");
        $stmt->bindParam(":betreff", $betreff);
        $stmt->bindParam(":inhalt", $inhalt);

        if ($stmt->execute() && $stmt->rowCount()) {
            return self::$db->lastInsertId();
        } else {
            return false;
        }
    }

    function writeNewsletterReceiverToDB($mailId, $userId, $status)
    {
        $stmt = self::$db->prepare("INSERT INTO newsletter_mail_empfaenger (mail_id, user_id, status) VALUES(:mailId, :userId, :status)");
        $stmt->bindParam(":mailId", $mailId);
        $stmt->bindParam(":userId", $userId);
        $stmt->bindParam(":status", $status);

        if ($stmt->execute() && $stmt->rowCount()) {
            return true;
        } else {
            return false;
        }
    }

    function unsubscribeFromNewsletter($email)
    {
        $stmt = self::$db->prepare("DELETE FROM newsletter_user WHERE email=:email");
        $stmt->bindParam(":email", $email);

        if ($stmt->execute()) {
            return true;
        } else {
            return false;
        }
    }
}